pub struct SignerFixture {
pub signer_with_stake: SignerWithStake,
pub protocol_signer: ProtocolSigner,
pub protocol_initializer: ProtocolInitializer,
pub protocol_closed_key_registration: ProtocolClosedKeyRegistration,
pub kes_secret_key_path: Option<PathBuf>,
pub operational_certificate_path: Option<PathBuf>,
}Expand description
A signer fixture, containing a signer entity with its corresponding protocol signer and initializer
Fields
signer_with_stake: SignerWithStakeprotocol_signer: ProtocolSignerprotocol_initializer: ProtocolInitializerprotocol_closed_key_registration: ProtocolClosedKeyRegistrationkes_secret_key_path: Option<PathBuf>The path to this signer kes secret key file
operational_certificate_path: Option<PathBuf>The path to this signer operational certificate file
Implementations
Sourceimpl SignerFixture
impl SignerFixture
Sourcepub fn try_new_with_protocol_parameters(
self,
protocol_parameters: ProtocolParameters,
) -> StdResult<Self>
pub fn try_new_with_protocol_parameters( self, protocol_parameters: ProtocolParameters, ) -> StdResult<Self>
Create a new SignerFixture with specific protocol parameters. This is useful to simulate some adversarial behaviors.
Sourceimpl SignerFixture
impl SignerFixture
Sourcepub fn sign<T: ToMessage>(&self, message: &T) -> Option<SingleSignature>
pub fn sign<T: ToMessage>(&self, message: &T) -> Option<SingleSignature>
Sign the given protocol message.
Sourcepub fn party_id(&self) -> PartyId
pub fn party_id(&self) -> PartyId
Shortcut to get the party id from the inner signer with stake
Sourcepub fn operational_certificate(&self) -> Option<ProtocolOpCert>
pub fn operational_certificate(&self) -> Option<ProtocolOpCert>
Get the operational certificate if any
Sourcepub fn compute_protocol_party_id_as_hash(&self) -> String
pub fn compute_protocol_party_id_as_hash(&self) -> String
Compute the party id hash
Note: will fail if the signers certification was disabled
Sourcepub fn verification_key_for_concatenation(
&self,
) -> ProtocolSignerVerificationKeyForConcatenation
pub fn verification_key_for_concatenation( &self, ) -> ProtocolSignerVerificationKeyForConcatenation
Get the verification key for concatenation
Sourcepub fn verification_key_signature_for_concatenation(
&self,
) -> Option<ProtocolSignerVerificationKeySignatureForConcatenation>
pub fn verification_key_signature_for_concatenation( &self, ) -> Option<ProtocolSignerVerificationKeySignatureForConcatenation>
Get the verification key signature for concatenation if any
Sourcepub fn verification_key_for_snark(
&self,
) -> Option<ProtocolSignerVerificationKeyForSnark>
pub fn verification_key_for_snark( &self, ) -> Option<ProtocolSignerVerificationKeyForSnark>
Get the verification key for snark if any
Sourcepub fn verification_key_signature_for_snark(
&self,
) -> Option<ProtocolSignerVerificationKeySignatureForSnark>
pub fn verification_key_signature_for_snark( &self, ) -> Option<ProtocolSignerVerificationKeySignatureForSnark>
Get the verification key signature for snark if any
Sourcepub fn kes_secret_key_path(&self) -> Option<&Path>
pub fn kes_secret_key_path(&self) -> Option<&Path>
Get the path to this signer kes secret key
Sourcepub fn operational_certificate_path(&self) -> Option<&Path>
pub fn operational_certificate_path(&self) -> Option<&Path>
Get the path to this signer operational certificate